# GALLEON
Code to generate a catalog of synthetic GW posteriors.
Single-event samples are generated according to Appendix A of [Fishbach et al. (2020)](https://iopscience.iop.org/article/10.3847/2041-8213/ab77c9).

The interpolator for $w = \Theta/4$ is taken from [E. Berti's webpage](https://pages.jh.edu/eberti2/research/) and described in [Dominik et al (2015)](https://arxiv.org/pdf/1405.7016.pdf).
